@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -278,8 +278,10 @@ sub _keyword {
 
     $pcdata =~ s/\s*$//;
 
-    if(my $system_provides = $self->config('system_provides')->{$keyword}) {
-      $pcdata = length $pcdata ? "$pcdata $system_provides" : $system_provides;
+    if($self->config('system_provides')) {
+      if(my $system_provides = $self->config('system_provides')->{$keyword}) {
+        $pcdata = length $pcdata ? "$pcdata $system_provides" : $system_provides;
+      }
     }
 
     return $pcdata;
